@@ -5,8 +5,8 @@
 *   rlgl library is an abstraction layer for multiple OpenGL versions (1.1, 2.1, 3.3 Core, ES 2.0)
 *   that provides a pseudo-OpenGL 1.1 immediate-mode style API (rlVertex, rlTranslate, rlRotate...)
 *
-*   NOTE: This example requires OpenGL 3.3 or OpenGL ES 2.0 for shaders support,
-*         OpenGL 1.1 does not support shaders but it can also be used.
+*   WARNING: This example is intended only for PLATFORM_DESKTOP and OpenGL 3.3 Core profile.
+*       It could work on other platforms if redesigned for those platforms (out-of-scope)
 *
 *   DEPENDENCIES:
 *       glfw3     - Windows and context initialization library
@@ -64,9 +64,6 @@
 #define RAYMATH_STATIC_INLINE
 #include "raymath.h"            // Vector2, Vector3, Quaternion and Matrix functionality
 
-#if defined(__EMSCRIPTEN__)
-    #define GLFW_INCLUDE_ES2
-#endif
 #include "GLFW/glfw3.h"         // Windows/Context and inputs management
 
 #include <stdio.h>              // Required for: printf()
@@ -136,6 +133,8 @@ int main(void)
 
     glfwWindowHint(GLFW_SAMPLES, 4);
     glfwWindowHint(GLFW_DEPTH_BITS, 16);
+    
+    // WARNING: OpenGL 3.3 Core profile only
     glfwWindowHint(GLFW_CONTEXT_VERSION_MAJOR, 3);
     glfwWindowHint(GLFW_CONTEXT_VERSION_MINOR, 3);
     glfwWindowHint(GLFW_OPENGL_PROFILE, GLFW_OPENGL_CORE_PROFILE);
