@@ -134,7 +134,8 @@ int main(void)
                            (Vector2){ 0, 0 }, 0.0f, WHITE);
 
             // Draw player current tile
-            DrawText(TextFormat("Current tile: [%i,%i]", playerTileX, playerTileY), 10, 10, 20, LIME);
+            DrawText(TextFormat("Current tile: [%i,%i]", playerTileX, playerTileY), 10, 10, 20, RAYWHITE);
+            DrawText("ARROW KEYS to move", 10, screenHeight-25, 20, RAYWHITE);
 
         EndDrawing();
         //----------------------------------------------------------------------------------
